FrAG-PELE: 
===========

A novel fragment-based growing tool for hit-to-lead in drug design

.. image:: docs/_images/movie_growing_phenyl.gif
    :height: 100px
    :width: 200 px
    :scale: 100%
    :align: center

Installation
=============

https://carlesperez94.github.io/frag_pele/installation.html

Getting Started:
=================

https://carlesperez94.github.io/frag_pele/first_steps.html


